import { dryOrder } from './DryOrder.data'
import { BasicColumn, FormSchema } from '/@/components/Table'
import { getTenantId } from '/@/utils/auth'
import { render } from '/@/utils/common/renderUtils'
import { rules } from '/@/utils/helper/validator'
//列表数据
export const columns: BasicColumn[] = [
	{
		title: '设备编号',
		align: 'center',
		dataIndex: 'code',
	},
	{
		title: '设备名称',
		align: 'center',
		dataIndex: 'name',
	},
	{
		title: '设备类型',
		align: 'center',
		dataIndex: 'type_dictText',
	},
	{
		title: '设备描述',
		align: 'center',
		dataIndex: 'remark',
	},
	{
		title: '车间id',
		align: 'center',
		dataIndex: 'shopId_dictText',
	},
	{
		title: '启用状态',
		align: 'center',
		dataIndex: 'enable',
		customRender: ({ text }) => {
			return render.renderSwitch(text, [
				{ text: '是', value: 'Y' },
				{ text: '否', value: 'N' },
			])
		},
	},
]
//查询数据
export const searchFormSchema: FormSchema[] = [
	{
		label: '设备编号',
		field: 'code',
		component: 'Input',
		colProps: { span: 6 },
	},
	{
		label: '设备名称',
		field: 'name',
		component: 'Input',
		colProps: { span: 6 },
	},
	{
		label: '设备类型',
		field: 'type',
		component: 'JDictSelectTag',
		componentProps: {
			dictCode: 'dry_eqp_type,name,id,tenant_id=' + getTenantId(),
		},
		colProps: { span: 6 },
	},
	{
		label: '车间id',
		field: 'shopId',
		component: 'JDictSelectTag',
		componentProps: {
			dictCode: 'dry_shop,name,id,tenant_id=' + getTenantId(),
		},
		colProps: { span: 6 },
	},
]
//表单数据
export const formSchema: FormSchema[] = [
	{
		label: '设备编号',
		field: 'code',
		component: 'Input',
		dynamicRules: ({ model, schema }) => {
			return [{ required: true, message: '请输入设备编号!' }, { ...rules.duplicateCheckRule('dry_equipment', 'code', model, schema)[0] }]
		},
	},
	{
		label: '设备名称',
		field: 'name',
		component: 'Input',
		dynamicRules: ({ model, schema }) => {
			return [{ required: true, message: '请输入设备名称!' }, { ...rules.duplicateCheckRule('dry_equipment', 'name', model, schema)[0] }]
		},
	},
	{
		label: '设备类型',
		field: 'type',
		component: 'JDictSelectTag',
		componentProps: {
			dictCode: 'dry_eqp_type,name,id,tenant_id=' + getTenantId(),
		},
		dynamicRules: ({ model, schema }) => {
			return [{ required: true, message: '请输入设备类型!' }]
		},
	},
	{
		label: '设备描述',
		field: 'remark',
		component: 'Input',
	},
	{
		label: '车间id',
		field: 'shopId',
		component: 'JDictSelectTag',
		componentProps: {
			dictCode: 'dry_shop,name,id,tenant_id=' + getTenantId(),
		},
		dynamicRules: ({ model, schema }) => {
			return [{ required: true, message: '请输入车间id!' }]
		},
	},
	{
		label: '启用状态',
		field: 'enable',
		component: 'JSwitch',
		componentProps: {},
		dynamicRules: ({ model, schema }) => {
			return [{ required: true, message: '请输入启用状态!' }]
		},
	},
	// TODO 主键隐藏字段，目前写死为ID
	{
		label: '',
		field: 'id',
		component: 'Input',
		show: false,
	},
]

/**
 * 流程表单调用这个方法获取formSchema
 * @param param
 */
export function getBpmFormSchema(_formData): FormSchema[] {
	// 默认和原始表单保持一致 如果流程中配置了权限数据，这里需要单独处理formSchema
	return formSchema
}

export interface dryEquipment {
	id: string
	code: string
	name: string
	type: string
	remark: string
	shop_id: string
	enable: string
	create_by: string
	create_time: Date
	update_by: string
	update_time: Date
	tenant_id: number
	order: dryOrder
}
